/* functions for communicating over a serial port.

    Copyright (C) 2007-2009 William Trevor King
    See COPYING for licence.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.

    The author may be contacted at <wking@drexel.edu> on the Internet,
    or write to Trevor King, Drexel University, Physics Dept., 3141
    Chestnut St., Philadelphia PA 19104, USA.
*/

typedef struct serial_port_struct serial_port_t;

/* Allocate memory for a serial port structure.
 * Returns 0 on success.
 */
extern int port_malloc(struct serial_port_struct **port);

/* Free memory for a serial port structure, setting *PORT = NULL on success
 */
extern void port_free(serial_port_t **port);

/* (re)connect to the port
 * Device string selects serial port, Unix "/dev/ttyS0" = MS Windows COM1 port.
 * Makes a local copy of the string, so you don't neet to keep yours...
 * Device is only read on the first connect, otherwise you might as well just send NULL.
 * returns 0 if a successful new connection is made */
extern int port_connect(serial_port_t *port, const char * const device);

/* closes the connection */
extern void port_close(serial_port_t *port);

/* Write LEN bytes of DATA to the serial port PORT
 * returns 0 on success
 */
extern int port_write(serial_port_t *port,
		      unsigned char *data,
		      size_t len);

/* read LEN bytes of DATA from the serial port PORT
 * DATA must be already allocated and of sufficient length.
 * returns 0 on success
 */
extern int port_read(serial_port_t *port,
		     unsigned char *data,
		     size_t len);
